#
# spec file for package udev
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           udev
Url:            http://www.kernel.org/pub/linux/utils/kernel/hotplug/udev.html
Version:        166
Release:        6.7.1
License:        LGPLv2.1+
Group:          System/Kernel
Summary:        A rule-based device node and kernel event manager
PreReq:         /bin/pidof /bin/rm /usr/bin/stat %insserv_prereq %fillup_prereq /usr/sbin/groupadd
Conflicts:      aaa_base < 11.2-57
Conflicts:      mkinitrd < 2.5.10-12
Conflicts:      util-linux < 2.16
Conflicts:      ConsoleKit < 0.4.1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libselinux-devel libsepol-devel
BuildRequires:  libusb-devel pciutils-ids usbutils
BuildRequires:  gperf libacl-devel pkg-config
BuildRequires:  glib2-devel gobject-introspection-devel
Source0:        ftp://ftp.kernel.org/pub/linux/utils/kernel/hotplug/%{name}-%{version}.tar.bz2
Source1:        udev-rpmlintrc
Source2:        baselibs.conf
Source60:       boot.udev
Source61:       boot.udev_retry

Patch10:        udev-ata_id.patch

%description
Udev creates and removes device nodes in /dev for devices discovered or
removed from the system. It receives events via kernel netlink messages
and dispatches them according to rules in /lib/udev/rules.d/. Matching
rules may name a device node, create additional symlinks to the node,
call tools to initialize a device, or load needed kernel modules.

%package -n libudev0
License:        LGPLv2.1+
Summary:        Dynamic library to access udev device information
Group:          System/Libraries

%description -n libudev0
This package contains the dynamic library libudev, which provides
access to udev device information

%package -n libudev-devel
License:        LGPLv2.1+
Summary:        Development files for libudev
Group:          Development/Libraries/Other
Requires:       libudev0 = %{version}-%{release}

%description -n libudev-devel
This package contains the development files for the library libudev, a
dynamic library, which provides access to udev device information.

%package -n libgudev-1_0-0
License:        LGPLv2.1+
Summary:        GObject library, to access udev device information
Requires:       libudev0 = %{version}-%{release}
Group:          System/Libraries

%description -n libgudev-1_0-0
This package contains the GObject library libgudev, which provides
access to udev device information.

%package -n libgudev-1_0-devel
License:        LGPLv2.1+
Summary:        Devel package for libgudev
Group:          Development/Libraries/Other
Requires:       libgudev-1_0-0 = %{version}-%{release}
Requires:       libudev-devel = %{version}-%{release}
Requires:       glib2-devel

%description -n libgudev-1_0-devel
This is the devel package for the GObject library libgudev, which
provides GObject access to udev device information.

%prep
%setup -q
%patch10 -p1

%build
# prevent man pages from re-building (xmlto)
find . -name "*.[1-8]" -exec touch '{}' \;
export V=1
%configure \
  --sysconfdir=%{_sysconfdir} \
  --sbindir=/sbin \
  --with-rootlibdir=/%{_lib} \
  --libexecdir=/lib/udev \
  --docdir=%{_docdir}/udev \
  --with-selinux \
  --with-systemdsystemunitdir=/lib/systemd/system \
  CFLAGS="$RPM_OPT_FLAGS"
make %{?_smp_mflags}

%install
make DESTDIR=$RPM_BUILD_ROOT install
rm -f $RPM_BUILD_ROOT/%{_libdir}/libudev.la
rm -f $RPM_BUILD_ROOT/%{_libdir}/libgudev-1.0.la
cp -ax README $RPM_BUILD_ROOT%{_docdir}/udev
%ifarch ppc ppc64
cp rules/arch/40-ppc.rules $RPM_BUILD_ROOT/lib/udev/rules.d/
%endif
%ifarch ia64
cp rules/arch/40-ia64.rules $RPM_BUILD_ROOT/lib/udev/rules.d/
%endif
%ifarch s390 s390x
cp rules/arch/40-s390.rules $RPM_BUILD_ROOT/lib/udev/rules.d/
%endif
install -m755 -D %{S:60} $RPM_BUILD_ROOT/etc/init.d/boot.udev
install -m755 -D %{S:61} $RPM_BUILD_ROOT/etc/init.d/boot.udev_retry
# don't run/short-cut old sysv init script with different name
ln -s udev-retry.service %{buildroot}/lib/systemd/system/udev_retry.service

%pre
/usr/sbin/groupadd -r tape 2> /dev/null || :
# kill daemon if we are not in a chroot
if test -f /proc/1/exe -a -d /proc/1/root; then
	if test "$(stat -Lc '%%D-%%i' /)" = "$(stat -Lc '%%D-%%i' /proc/1/root)"; then
		if test -x /sbin/udevd; then
			kill $(pidof udevd) >/dev/null 2>&1 || :
		fi
	fi
fi

%post
%{fillup_and_insserv -Y boot.udev}
%{fillup_and_insserv -Y boot.udev_retry}
# add KERNEL name match to existing persistent net rules
sed -ri '/KERNEL/ ! { s/NAME="(eth|wlan|ath)([0-9]+)"/KERNEL=="\1*", NAME="\1\2"/}' \
    /etc/udev/rules.d/70-persistent-net.rules >/dev/null 2>&1 || :
# cleanup old stuff
rm -f /etc/sysconfig/udev
rm -f /etc/udev/rules.d/20-cdrom.rules
rm -f /etc/udev/rules.d/55-cdrom.rules
rm -f /etc/udev/rules.d/65-cdrom.rules
# convert old database files
/sbin/udevadm info --convert-db >/dev/null 2>&1 || :
# start daemon if we are not in a chroot
if test -f /proc/1/exe -a -d /proc/1/root; then
	if test "$(stat -Lc '%%D-%%i' /)" = "$(stat -Lc '%%D-%%i' /proc/1/root)"; then
		if test -x /sbin/udevd; then
			/sbin/udevd --daemon >/dev/null 2>&1 || :
		fi
	fi
fi

%postun
%insserv_cleanup

%post -n libudev0 -p /sbin/ldconfig

%postun -n libudev0 -p /sbin/ldconfig

%post -n libgudev-1_0-0 -p /sbin/ldconfig

%postun -n libgudev-1_0-0 -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
/sbin/udevd
/sbin/udevadm
%dir /lib/udev/
/lib/udev/*
%dir /lib/udev/keymaps
/lib/udev/keymaps/*
/lib/udev/keyboard-force-release.sh
%dir /lib/udev/rules.d/
/lib/udev/rules.d/*.rules
%{_sysconfdir}/init.d/boot.udev
%{_sysconfdir}/init.d/boot.udev_retry
%dir %{_sysconfdir}/udev/
%dir %{_sysconfdir}/udev/rules.d/
%config(noreplace) %{_sysconfdir}/udev/udev.conf
%dir %{_prefix}/lib/ConsoleKit
%dir %{_prefix}/lib/ConsoleKit/run-seat.d
%{_prefix}/lib/ConsoleKit/run-seat.d/udev-acl.ck
%{_mandir}/man?/*.[0-9]*
%{_datadir}/pkgconfig/udev.pc
%doc %{_docdir}/udev
%dir /lib/udev/devices/
%dir /lib/systemd/system
/lib/systemd/system/udev*.service
%dir /lib/systemd/system/basic.target.wants
/lib/systemd/system/basic.target.wants/udev*.service

%files -n libudev0
%defattr(-,root,root)
/%{_lib}/libudev.so.*

%files -n libudev-devel
%defattr(-,root,root)
%{_includedir}/libudev.h
%{_libdir}/libudev.so
%{_libdir}/pkgconfig/libudev.pc
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%dir %{_datadir}/gtk-doc/html/libudev
%{_datadir}/gtk-doc/html/libudev/*

%files -n libgudev-1_0-0
%defattr(-,root,root)
/%{_lib}/libgudev-1.0.so.*
%{_libdir}/girepository-1.0/GUdev-1.0.typelib

%files -n libgudev-1_0-devel
%defattr(-,root,root)
%dir %{_includedir}/gudev-1.0
%dir %{_includedir}/gudev-1.0/gudev
%{_includedir}/gudev-1.0/gudev/*.h
%{_libdir}/libgudev-1.0.so
%{_libdir}/pkgconfig/gudev-1.0.pc
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%dir %{_datadir}/gtk-doc/html/gudev
%{_datadir}/gtk-doc/html/gudev/*
%{_datadir}/gir-1.0/GUdev-1.0.gir

%changelog
* Tue Apr 26 2011 kay.sievers@novell.com
- run ata_id only on SPC-3 or later optical drives (bnc#679277)
* Sat Feb 12 2011 sndirsch@novell.com
- removed 79-kms.rules (bnc #609607, comment #42)
* Thu Feb 10 2011 kay.sievers@novell.com
- version 166
  - updated keymaps
  - add qemu usb autosuspend rules
* Thu Dec 16 2010 kay.sievers@novell.com
- version 165
  - the database format changed
    the old format is converted to the new one during update
  - libudev supports:
    udev_device_get_is_initialized()
    udev_enumerate_add_match_is_initialized()
  - Gudev supports GUdevEnumerator, TAG and timestamps
* Thu Nov 11 2010 coolo@novell.com
- own parent dirs for systemd files
* Sat Oct 23 2010 kay.sievers@novell.com
- version 164
  - GUdev moved from /usr to /
  - cdrom_id fixes
  - new keymaps
* Thu Oct  7 2010 kay.sievers@novell.com
- version 163
  - cdrom bug fixes
  - scsi_id ID_TARGET_PORT= export
  - updated systemd integration
* Fri Sep  3 2010 kay.sievers@novell.com
- version 162
  - cdrom_id bug fixes for DVD media
  - unconditionally enable udev on systemd bootups
  - new/updated keymaps
  - do not create persistent network rules in qemu/kvm
* Wed Aug 11 2010 kay.sievers@novell.com
- version 161
  - fixed device rename dabase file handling
  - fixed keymaps
  - improved cdrom_id
* Sat Jul 24 2010 kay.sievers@novell.com
- update systemd service installation
* Wed Jul 14 2010 kay.sievers@novell.com
- drop systemd-units
* Wed Jul 14 2010 kay.sievers@novell.com
- conflict with systemd < 3
* Mon Jul 12 2010 kay.sievers@novell.com
- disable boot.udev_retry init script
* Mon Jul 12 2010 kay.sievers@novell.com
- Update to version 160
  - fix broken persistent tape naming rules
  - fix systemd abstract namespace handling
* Fri Jul  9 2010 kay.sievers@novell.com
- fix systemd service file uninstallation
* Fri Jul  9 2010 kay.sievers@novell.com
- build against systemd-units
- activate systemd udev.service files
* Wed Jul  7 2010 kay.sievers@novell.com
- Update to version 159
- remove all static device nodes from /lib/udev/devices/,
  they are provided by the kernel modules themselves
- install systemd service files
* Mon Jul  5 2010 xwhu@novell.com
- bnc#619283, Keep the udev db from initramfs.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Wed Jun  2 2010 kay.sievers@novell.com
- Update to version 157
  - support kernel commandline debug switches to help debugging
    kernel module load system crashes at bootup
  - allow to import properties from kernel commandline
- move kms rules from tarball to package
* Tue May 25 2010 kay.sievers@novell.com
- Update to version 156
  - fix /proc/self/fd symlink
  - do not call blkid on audio and empty CDs (bko#15757)
  - fix wait for event queue sequence (bnc#581612)
* Mon May 24 2010 kay.sievers@novell.com
- Update to version 155
  - copy the content of /lib/udev/devices to /dev
  - create the standard symlinks like /dev/std{in,out,err},
    /dev/core, /dev/fd, ...
  - use static node information provided by kernel modules
    and creates these nodes to allow module on-demand loading
  - possibly apply permissions to all static nodes from udev
    rules which are annotated to match a static node
* Tue May 11 2010 kay.sievers@novell.com
- Update to version 154
  - ignore NAME="" instructions - udev will not delete kernel nodes
    like device-mapper tries to do (bnc#601715)
  - filter inotify events for *.rules files - prevent inotify loops
    caused by deleted nodes which are watched (bnc#601715)
- drop the device-mapper rules which are part of  the device-mapper
  package now
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Wed Apr 21 2010 kay.sievers@novell.com
- Update to version 153
  - fix broken firmware loader
* Tue Apr 20 2010 kay.sievers@novell.com
- Update to version 152
  - firmware loader: missing firmware file fix
  - cdrom_id: O_EXCL, phantom-media fixes
  - new and fixed keymaps
  - trigger by default sends "change" events now instead of "add"
  - all_partitions, ignore_remove options are removed
- use trigger --action=add at coldplug time in init script
- drop device-mapper rules, which are shipped by dm now
* Tue Mar  9 2010 mmarek@suse.cz
- Do not install md rules, the mdadm package will install it's own
  version (fate#307478).
* Wed Feb 17 2010 kay.sievers@novell.com
- do not install device nodes provided by devtmpfs
* Fri Feb  5 2010 kay.sievers@novell.com
- fix firmware loading issue (bnc#574904)
* Mon Jan 25 2010 kay.sievers@novell.com
- Update to version 151
  - remove outdated documentation
  - do not remove device node while the kernel device is around
- add KMS rules file
* Fri Jan  8 2010 kay.sievers@novell.com
- Update to version 150
  - new keymaps
  - new keyboard force-release handling
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Thu Dec  3 2009 kay.sievers@novell.com
- Update to version 149
  - fix possible endless loop in input_id
* Wed Dec  2 2009 kay.sievers@novell.com
- Update to version 148
  - the gudev API is no longer marked as experimental
  - gudev introspection is enabled by default now
  - option "last_rule" does no longer exist
  - udev-acl tool requires ConsoleKit version 0.4.1
  - NAME= instructions got removed
    Kernel 2.6.31 supplies the needed names
  - NAME="%%k" causes a warning now. It's is and always was completely
    superfluous and breaks kernel supplied DEVNAMEs
  - Multiple devices claiming the same names in /dev are limited to
    symlinks only now. Mixing identical symlink names and node names
    is not supported.
  - BUS=, SYSFS{}=, ID= are long deprecated and should be
    SUBSYSTEM(S)=, ATTR(S){}=, KERNEL(S)=. It will cause a warning
    once for every file.
  - The support for the deprecated IDE devices has been removed from
    the default set of rules.
  - The option "ignore_device" does no longer exist.
* Mon Oct  5 2009 kay.sievers@novell.com
- add baselibs.conf (bnc#544448)
* Fri Aug 14 2009 kay.sievers@novell.com
- new upstream release 146
  - fixed "failed" events tracking
  - new keymaps, new modem, hid2hci updated
  - fixed trigger order for sound devices
* Mon Jul 13 2009 kay.sievers@novell.com
- new upstream release 145
  fix crash when workers are busy, rules are changed and workers killed
  use qsort() to speed up sorting a large udevadm trigger list
- add static nodes for /dev/ptmx /dev/tty*
* Mon Jul  6 2009 kay.sievers@novell.com
- new upstream release 144
  fix hid2hci rules
  the now empty /etc/scsi_id.config is gone
  check /lib/firmware for updates
- init script: add --type=, also trigger class/bus events
* Thu Jun 18 2009 kay.sievers@novell.com
- new upstream release 143
    merge with udev-extras package, and provide:
    gudev - gobject libudev access (DeviceKit, NetworkManager, ...)
    hid2hci - bluetooth switch
    keymap - multimedia button keycode handling
    modem-modeswitch - 3G modem setup
    udev-acl - device access for local users
    usb-db - names for usb and pci devices from usb/pci db
    v4l_id - basic properties for video4linux devices
    event process fork replaced by dynamic worker processes
    devtmpfs DEVNAME support
    drop libvolume_id and vol_id, replaced by util-linux's blkid
- drop modprobe config, floppy.ko has the proper modalias now
- drop some static nodes
* Thu Apr  9 2009 kay.sievers@novell.com
- new upstream release 141
- provide udev events over netlink
* Tue Mar 24 2009 kay.sievers@novell.com
- new upstream release 140
  udevadm settle - add --seq-start= --seq-end=
* Mon Mar  9 2009 mmarek@suse.cz
- renamed /etc/modprobe.d/pnp-aliases.conf to 50-pnp-aliases.conf
  so that 99-local.conf comes last
* Tue Mar  3 2009 kay.sievers@novell.com
- new upstream release 139
  fixes for the block device monitor
- the deprecated udevadm and udevsettle symlinks are removed now
* Thu Feb 19 2009 kay.sievers@novell.com
- new upstream release 138
- block devices are watched for metadata changes from userspace
  like mkfs, e2label, mkswap, ...
- add .conf to /etc/modprobe.d/pnp-aliases
* Fri Jan 23 2009 kay.sievers@novell.com
- new upstream release 137
- create "tape" system group
- usb_id: handle "ATAPI" subclass as "SCSI"
* Mon Jan 12 2009 kay.sievers@novell.com
- new upstream release 136
- /dev/serial/by-{id,path}/ links for ttyUSB devices
- let libvolume_id refuse to detect filesystem with multiple
  non-compatible signatures
- improved rule parser, reduces memory foootprint for large
  rulesets from 1.2MB to 80kb
- removed limit of the number of keys per rule (no more maximum
  of 5 ATTR/ENV keys per rule)
- NAME assignment is no longer special cased, later rules which
  assign a NAME value again, overwrite the former value
- /dev/{block,char}/<maj>:<min> symlinks
- updated "default udev rules" assign: disk, cdrom, floppy, tape,
  audio, video, lp, tty, dialout, kmem
* Thu Jan  8 2009 kay.sievers@novell.com
- fix cd rule generator for multiple optical drives (bnc#462663)
* Thu Dec 18 2008 kay.sievers@novell.com
- fix path_id for SAS devices (bnc#459934)
* Fri Nov 21 2008 kay.sievers@novell.com
- fix fibre channel path_id handling (bnc#447275)
- load floppy module on ancient systems (bnc#439170)
- do not probe s390 btibm tapes (bnc#448340)
- cciss rule fix (bnc#449110)
* Mon Nov 17 2008 kay.sievers@novell.com
- fix "delete /dev/.udev/uevent_seqnum" patch (bnc#444636)
* Wed Nov  5 2008 kay.sievers@novell.com
- vol_id: fix logging (bnc#441835)
- md rules: add support for new device naming in mdadm-3.0 (upstream)
- udevd: delete /dev/.udev/uevent_seqnum on exit (bnc#413059)
* Fri Oct 31 2008 kay.sievers@novell.com
- escape space characters in dm and md symlinks (bnc#417060)
- fix floppy modalias (bnc#439170)
- remove timeout settings for SCSI devices (upstream)
- always match on ACTION=="add|change" to not break device
  naming if the kernel issues a "change" event (upstream)
* Thu Oct 23 2008 kay.sievers@novell.com
- fix persistent netif rule writing (bnc#438029)
- detect swap with larger PAGE_SIZE (bnc#433028)
* Wed Oct  1 2008 kay.sievers@novell.com
- fix bug which prevented large-file compilation, which made vol_id
  not recognize raid signatures at the end of volumes (bnc#428660)
- create both by-id/ieee-* and by-id/scsi-* links (bnc#422330)
- read hpfs label/uuid (bnc#420526)
* Thu Sep 11 2008 kay.sievers@novell.com
- new upstream release 128
  libudev work
- warn when symliks to udevadm are used, they will be removed soon
* Fri Aug 29 2008 kay.sievers@novell.com
- new upstream release 127
  provide libudev shared library
  optical drives are probed for filesystem at last session
  do not probe optical drives for raid (bnc#419195)
  libvolume_id version 1
  firmware loader looks in /lib/firmware/$(uname -r)
- create libudev0 libudev-devel packages
- rename package libvolume_id package to libvolume_id1
- load acpi:* modalias instead of pnp:*
* Wed Aug 20 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Sat Aug 16 2008 kay.sievers@novell.com
- fix init script LSB warning
* Tue Jul 29 2008 kay.sievers@novell.com
- new upstream release 126
  use autotools
- use devnum+inode in chroot detection (bnc#408959)
* Thu Jun 26 2008 kay.sievers@novell.com
- new upstream release 125
  default rules are in /lib/udev/rules.d/, only custom and
  user editable rules should go into /etc/udev/rules.d/ now
- do not mark rules as config
- conflict with mkinitrd < 2.3
- add writing_udev_rules to %%doc (bnc#404173)
- add noreplace to some config files
* Thu Jun 12 2008 kay.sievers@novell.com
- new upstream release 124
  use bsg device nodes for tape drives
* Mon May 26 2008 kay.sievers@novell.com
- handle ibmveth "locally administered" MAC addresses (bnc#339482)
* Tue May 20 2008 kay.sievers@novell.com
- run edd_id only for sd* and hd* disks (bnc#372199)
* Tue Apr  1 2008 kay.sievers@novell.com
- new upstream release 120
  no longer install udevmonitor and udevtest symlinks
- add KERNEL== match to existing persistent net rules (bnc#354141)
- remove Conflicts: lvm - it is not a udev, but a kernel dependency
- Conflicts: with older mkinitrd (bnc#375245)
- change ldconfig call to "-p /sbin/ldconfig"
- remove ancient Obsoletes: hotplug
* Sat Mar 15 2008 kay.sievers@novell.com
- new upstream release 119
- fix persistent net rules for identical MAC addresses (bnc#365501)
- improve ext4 detection
* Thu Mar  6 2008 lmb@suse.de
- Change requirement for lvm2 to a conflict with earlier versions.
* Mon Mar  3 2008 lmb@suse.de
- Add lvm2 >= 2.02.33 requirement.
* Wed Dec 19 2007 kay.sievers@novell.com
- new upstream release 118
  volume_id: check if a device returns data before probing, so
  we run only once into a timeout for dead devices
  create_floppy_devices: fix for more than one floppy
* Tue Nov 13 2007 kay.sievers@novell.com
- new upstream release 117
  all udev tools are merged into udevadm
- call udevadm directly instead of old tool names
- create dynamic rule to provide a /dev/root symlink
* Wed Oct 10 2007 kay.sievers@novell.com
- new upstream release 115
  switch to default udev rules (merge of openSUSE with Fedora)
  split out architecture specific rules into separate files
  add network interface type match to all persistent net rules
- do not install rules for other architectures
- add netif type match for all wireless devices (bnc#309081)
- start udevd without checking for running processes (bnc#329742)
* Tue Sep 18 2007 kay.sievers@novell.com
- add /dev/lp0 to static devices (bnc#308990)
- fix some static device nodes perms to match rule perms 0600 -> 0660
- add /etc/modprobe.d/pnp-aliases for floppy autoload (bnc#308964)
* Wed Sep 12 2007 kay.sievers@novell.com
- ignore device node names while restoring symlinks (bnc#309294)
- remove rtc from /lib/udev/devices (device no longer in the kernel)
* Thu Sep  6 2007 kay.sievers@suse.de
- add realtime clock nodes (bnc#287539)
* Wed Aug 22 2007 kay.sievers@suse.de
- fix wrong logic of DRIVER in persistent net rules
  (vmware creates multiple rules for the same device)
- increase timeout for WAIT_FOR_SYSFS to 10 seconds (bnc#306305)
* Mon Aug 13 2007 kay.sievers@suse.de
- /dev/net/tun is 0666, also when module is not loaded
- fix squashfs detection (bnc#300942)
- probe only partitions for filesystems; the kernel does not notify
  us about media changes of unformatted media
- add iowarrior rule (bnc#300082)
* Sun Aug  5 2007 kay.sievers@suse.de
- new upstream relase 114
  log netif rename to kernel log (dmesg)
- git-HEAD patch included in tarball
* Fri Jul 27 2007 kay.sievers@suse.de
- touch man pages to prevent re-build
* Fri Jul 27 2007 kay.sievers@suse.de
- update to current git version
  fix bug introduced in inotify handling (inverted match)
  trigger "driver" events (needs kernel support)
  S/390 persistent network support
  fix bug introduced in persistent net rule writing (NAME== match)
* Mon Jul 16 2007 kay.sievers@suse.de
- update to current git version
  support ignore_error option for RUN key
  allow to match against SYMLINK and NAME
  allow to add dynamic rules to /dev/.udev/rules.d/
- prepare for creation of /dev/root (fate#302411)
- add symlink scd* for sr* optical drives (bnc#291401)
- add ignore_error option to modprobe rules
* Thu Jul  5 2007 kay.sievers@suse.de
- modprobe all requested modules without relying on sysconfig (#286132)
- rules to load TI FlashMedia modules
- remove hwup call from boot.udev
- do not care about cleaning /events, eventrecorder is gone
* Sun Jun 24 2007 kay.sievers@suse.de
- rpmlint fixes
- remove ChangeLog and other files from doc directory
- add %%insserv_cleanup
* Sat Jun 23 2007 kay.sievers@suse.de
- new upstream relase 113
  distinguish more reliably between partitions and disk in persistent rules
  atomically replace existing files (prepare for handling /dev/mapper/)
  udevd: do not use syslog for --verbose
- add volume_id version dependency
* Mon Jun  4 2007 kay.sievers@suse.de
- new upstream relase 112
- changes for integration of libvolume_id into util-linux
- prepare for userspace driver binding
- add TEST=="<file>" key
- upstream integration of cciss devices into persistent links
- drop scsi module loading rules, the kernel has modalias strings now
* Thu May 24 2007 hare@suse.de
- Add support for cciss devices.
* Thu May 10 2007 kay.sievers@suse.de
- new upstream release 111
  use fgets() to read /proc/stat, should fix errors on very big boxes
  volume_id: use md native uuid format
  volume_id: add DDF probing (untested)
- add persistent /dev/disk/by-id/dm-{name,uuid}-* links
- prepare for persistent /dev/disk/by-id/md-{name,uuid}-* links
* Tue May  1 2007 kay.sievers@suse.de
- new upstream release 110
- remove eventrecorder.sh
- volume_id: add support for md metadata-format 1.0, 1.1, 1.2
- add fuse rule
- add /dev/bus/usb/-nodes rule for new libusb-nodes
- most suse rules in the udev package moved to the default rules
  install all default rules and the remaining custom suse rules
- enable the udev persistent rules generator for network devices
  this replaces the one provided from sysconfig
* Tue Apr 24 2007 kay.sievers@suse.de
- new upstream release 109
- add Short-Description: to init scripts
- install the rules from the suse directory in the udev package
- disable /etc/udev/rules.d/65-cdrom.rules which is created by
  the installer, and enable the udev persistent rules generator to
  provide persistent optical device-links for all devices, not only
  the ones present at installation time
- first cut of md persistent device-naming based on change-events
  (hope we can add "md auto-assembly" to this rules file soon)
- removal of /usr/bin/udev.count_events, it's just udevsettle, and
  possible callers should be fixed and calll udevsettle directly
- delete load_floppy_module.sh, the modalias it tries to request,
  seems not to exist
* Wed Mar 28 2007 kay.sievers@suse.de
- new upstream release 108
- assign lower priority to dm-* symlinks, so EVMS-like devices
  don't overwrite symlinks unless an explicit rule may specify it
- add (but comment it out for now) rule for new usb-device-nodes
* Thu Mar 22 2007 kay.sievers@suse.de
- use ata_id for libata sd* devices; id's may be truncated by the
  scsi stack to 16 chars (#255413)
* Mon Mar 19 2007 kay.sievers@suse.de
- new upstream release 107
  - introduce symlink priorities for devices
  - dasd_id is gone, s390-tools provides dasdinfo and rules
  - append target:lun to usb-storage devices (#255757)
- persistent tape rules
- install (but disable for now) upstream persistent network-interface
  and persistent optical drive link rules
- don't install evil static lib from libvolume_id-devel
* Wed Mar  7 2007 rguenther@suse.de
- fix order of changelog entries
* Sat Mar  3 2007 kay.sievers@suse.de
- new upstream release 106
  add persistent tape names
- fix create_floppy_devices permissions (#244593)
* Sat Feb  3 2007 kay.sievers@suse.de
- new upstream release 105
  fix volume_id's linux_raid detection
* Wed Jan 10 2007 kay.sievers@suse.de
- create raw devices at /dev/raw/ (#231213)
* Tue Jan  2 2007 kasievers@suse.de
- new upstream release 104
  patch merged
* Wed Nov 15 2006 kay.sievers@suse.de
- fix endianess bug in libvolume_id for md raid (#221351)
- don't catch raw1394 as raw blockdev (#219555)
* Tue Nov 14 2006 kay.sievers@suse.de
- add empty "Required-Start:" to boot.udev (LSB you rock!) (#200174)
- put "noz*" devices in "uucp" group (#217739)
- don't try to create persistent /dev/disk/by-* links for md-raid,
  it will need its own rule file for special handling
* Fri Oct 20 2006 kay.sievers@suse.de
- new upstream release 103
  improve via_raid detection, cause some weird mp3-players have
    that signature all over the place
- run mmc modprobe only at "add" events
* Sun Oct 15 2006 kay.sievers@suse.de
- fix invalid rule for mmc card support
* Fri Oct 13 2006 fseidel@suse.de
- support for mmc/sd cards
* Tue Oct 10 2006 kay.sievers@suse.de
- new upstream release 102
  full support for future sysfs layout changes
  fix path_id for SAS devices
- create compat rules for /dev/disk/ for libata switch (#211236)
* Sat Sep 30 2006 kay.sievers@suse.de
- new upstream release 101
  udevd now has --debug-trace option for bootup in trace mode
  PHYSDEV* warnings patch upstream
- udevd restart - replace YAST_IS_RUNNING with chroot detection (#204759)
* Wed Sep 20 2006 schwab@suse.de
- Set mode of /dev/net/tun to 0666, access restrictions are now enforced
  by the kernel.
* Wed Sep  6 2006 kay.sievers@suse.de
- new upstream release 099
  create files instead of  symlinks in /dev/.udev/{queue,failed}
- add cdrom_id rule
- do not restart when YAST_IS_RUNNING is set
* Mon Aug 28 2006 aj@suse.de
- Prerequire pidof since it's needed in %%pre section.
* Wed Aug 23 2006 kay.sievers@suse.de
- new upstream release 098
  more consistent key naming scheme:
    BUS, ID, SYSFS, DRIVER
    are now:
    SUBSYSTEMS, KERNELS, ATTR/ATTRS, DRIVERS
    SUBSYSTEM, KERNEL, ATTR matches the event device
    SUBSYSTEMS, KERNELS, ATTRS match against all parent devices
    (the old names still work, DRIVER should be DRIVERS now)
  ATTR{file}="value" can set sysfs attributes now
  udevinfo works for all devices now
- use new key names in SUSE rules
- restart udevd on upgrade
- warn if a deprecated PHYSDEV* value or the 'device' link is used
* Sun Aug 13 2006 kay.sievers@suse.de
- new upstream release 097
  increase buffer to read /proc/stat (#193298)
  device mapper sends "change" now instead of "online"
- create disk/by-uuid/ for 'crypto' type devices
- add ht* tapes to 'disk' group (#194008)
- add all partition nodes for ide_floppy (ZIP) drives (#191156)
- load ide-scsi if an ide tape is detected (#192430)
* Fri Jul 28 2006 olh@suse.de
- boot.udev_retry requires boot.rootfsck, optional $local_fs (#181972)
  remove boot.preload_early from boot.udev to avoid circular dependency,
  boot.udev is the very first B script to run
* Sun Jul  9 2006 kay.sievers@suse.de
- new upstream release 096
  fix for path_id and kernel 2.6.18 (#191165)
* Tue Jul  4 2006 kay.sievers@suse.de
- new upstream release 095
* Mon Jun 12 2006 kay.sievers@suse.de
- update from upstream version 085 to 094
  (integrating previous patches)
- split off libvolume_id package
- /sbin/*id moved to /lib/udev
* Thu Jun  1 2006 kay.sievers@suse.de
- wait for sysfs for net devices (#165050)
- switch to "online" events for device mapper devices (#175972)
- skip lvm snapshot devices from persistent rules (#178321)
* Fri May 26 2006 kay.sievers@suse.de
- path_id: prevent endless loop for SAS devices (#178343)
* Thu May 25 2006 kay.sievers@suse.de
- remove boot.proc dependency from boot.udev (#178754)
- fix '==' vs. '=' in rules
* Fri May 19 2006 hare@suse.de
- Add path_id for iSCSI devices (#176804)
* Wed May 10 2006 kay.sievers@suse.de
- fix edd_id (null) output (#174296)
- use different uuid for NetWare nss volume
* Mon May  8 2006 kay.sievers@suse.de
- add NetWare volume detection (#170255)
* Mon May  1 2006 kay.sievers@suse.de
- fix offsetof build failure with new glibc
* Thu Apr 27 2006 kay.sievers@suse.de
- don't use startproc, we need to wait for udevd to be initialized
  create /dev/.udev directory from udevd for seqnum export (#169103)
- never fail in boot.udev_retry (#170302)
* Mon Apr 24 2006 kay.sievers@suse.de
- export initial seqnum from udevd (#169064)
- fix wrong use of "==" and "=" - future udev versions will fail here
* Fri Apr 21 2006 kay.sievers@suse.de
- fix silly typo in dm persistent rules (#163073)
- adapt path_id for SAS devices (#164085)
* Thu Apr 13 2006 kay.sievers@suse.de
- fix inifinite loop in path_id for SAS devices (#164085)
- fix event trigger order
* Fri Apr  7 2006 kay.sievers@suse.de
- move raw device nodes to /dev/raw/* (#164219)
- set udevsettle timeout to 180 seconds
- add Handspring "pilot" link
* Tue Apr  4 2006 kay.sievers@suse.de
- export current seqnum to /dev/.udev/uevent_seqnum to
  be able to compare against the kernel seqnum and make
  sure that there are no more events to expect. Add
  udevsettle to wait for events. (#163010).
* Fri Mar 31 2006 olh@suse.de
- do not provide tty0-7, only tty1 (162365)
* Wed Mar 22 2006 kay.sievers@suse.de
- path_id: add bus prefix to USB path
- path_id: add it to the package instead of patching it
- fix rule for skipping removable IDE drives
- don't create label and uuid links for raid members
* Tue Mar 21 2006 kay.sievers@suse.de
- add persistent links for SCSI tapes (from Hannes)
- add USB support to path_id (from Hannes)
- make /dev/input/by-path/ working with the new path_id
* Mon Mar 20 2006 kay.sievers@suse.de
- fix force-reload to use udevtrigger
* Thu Mar 16 2006 kay.sievers@suse.de
- add udevtrigger from Hannes to replace the shell script event
  trigger which doesn't work with 1000's of devices (#148043)
- allow comma in filenames (SGI)
- remove group "audio" from /dev/rtc (#158338)
* Wed Mar  8 2006 kay.sievers@suse.de
- handle "drivers" events (ipw wants to start the daemon)
- skip persistent links for removable IDE drives (event loop)
* Wed Mar  1 2006 kay.sievers@suse.de
- add path_id SAS support from Hannes
* Thu Feb 23 2006 kay.sievers@suse.de
- fix queue export
* Thu Feb 16 2006 kay.sievers@suse.de
- version 85
  - merge cramfs patch upstream
  - abort WAIT_FOR_SYSFS if device goes away
* Wed Feb 15 2006 schwab@suse.de
- Add write permission to /dev/mmtimer.
* Sun Feb 12 2006 olh@suse.de
- fix cramfs detection for bigendian (#148855)
  provide static hvc0, hvsi0 and hvsi1 nodes (#145405)
* Mon Feb  6 2006 coolo@suse.de
- readding the boot.preload_early to the udev init script
* Mon Jan 30 2006 kay.sievers@suse.de
- add persistent device links for input devices (#143096)
- remove sysconfig cleanup (#140123)
* Mon Jan 30 2006 kasievers@suse.de
- version 084
  - fix bug with BUS and SYSF at the same level, where SYSFS is
    expected to read the attribute at the device we receice the
    event for
  - add more debug to sysfs operations
* Fri Jan 27 2006 kay.sievers@suse.de
- version 83
  - man page update
  - don't add $SUBSYSTEM to executed programs
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 kay.sievers@suse.de
- version 82
  - replace patch from package with upstream version
  - fix for RUN to be able to contain DEVLINKS
  - don't install long obsolete udev, udevsend, udevstart binaries
  - increase uevent buffer size to match the increased
    kernel buffer size needed for the input MODALIAS on some boxes
- fix scsi device timeout setting rules
* Mon Jan 23 2006 kay.sievers@suse.de
- path_id and usb_id patch
- use /sys/kernel/uevent_helper instead of /proc/sys/kernel/hotplug
- wait for SCSI sysfs file
- get rid of "device" symlink usage in rules
* Mon Jan 23 2006 zoz@suse.de
- adapt show_event_log to changes of udev log messages
* Mon Jan 16 2006 kay.sievers@suse.de
- fix %%b and clarify udev man page
- remove input.sh and ide.sh - both have modalias in the latest
  kernel now and can be handled by sysconfig.
* Sat Jan 14 2006 kay.sievers@suse.de
- version 081
  - run filesystem guessing in vol_id without privileges
  - add DEVLINKS to "remove" event
- remove non-working mount.sh (may go into sysconfig, if we need it)
* Mon Jan  9 2006 kay.sievers@suse.de
- version 080
  - get rid of libsysfs
  - path_id: fix sed character class
* Fri Dec 23 2005 kay.sievers@suse.de
- version 079 (nothing worth to mention)
- use scsi_id.config from udev tree
- support "palmOne Handheld" "pilot" link
* Sat Dec 17 2005 kasievers@suse.de
- version 078
    fix segfaulting floppy helper
    export symlinks to environment
- use DEVLINKS for mount.sh
- add WAIT_FOR_SYSFS for "address" file of network devices
* Fri Dec 16 2005 kay.sievers@suse.de
- fix typo in DVB rule
- remove sonypi and toshiba device node
- move mount to own rule to place default rules in initramfs
* Tue Dec  6 2005 kay.sievers@suse.de
- move sysconfig rules to sysconfig package
- add --noopencount to dmsetup call
* Sun Dec  4 2005 kay.sievers@suse.de
- version 077 (nothing exciting)
- remove kino rules (sent to kino maintainer)
- update README.debug
- rename rules files:
    /etc/udev/rules.d/05-udev-early.rules
    /etc/udev/rules.d/50-udev-default.rules
    /etc/udev/rules.d/95-udev-late.rules
- tools in /lib/udev/tool can be called with RUN+="tool" now
* Mon Nov 28 2005 kay.sievers@suse.de
- load_ide_modules.sh: let it work with more devices than hda-hdf
- load_ide_modules.sh: stupid me, add shebang #135618
- load_ide_modules.sh: rename to ide.sh
- input_device.sh: add a actually working version from Marco
- input_device.sh: rename to input.sh
* Thu Nov 24 2005 kay.sievers@suse.de
- remove Requires: (CRITICAL CYCLE)
- remove ISDN, goes into ISDN package
- move HAL rule to HAL package
- move alsa rules to alsa package
- setup static device configs with boot.udev script
- wait for ide proc-file to appear
- let udev.count_events wait for the event queue directory
- cleanup load_ide_modules and firmware
* Fri Nov 18 2005 kay.sievers@suse.de
- version 076
  o move some more udev helpers to /lib/udev
  o better queue export
- fix scsi__host which needs "_" quoted "_"
- cleanup boot script (/dev init will go into "boot")
- wait for all events to finish
- boot.udev_retry - retry failed events after localfs
- ignore driver + module events
* Wed Nov 16 2005 kay.sievers@suse.de
- version 075git20051117
  o all wait-for-sysfs is removed
  o export event queue to filesystem
- add wait-for-sysfs rule
- add scsi timeout rules (Hannes)
- fix spelling of OnStream name
- remove /sys from hwup calls
* Thu Nov 10 2005 kay.sievers@suse.de
- remove doubled dm rules
- fix block device event order
- simplify coldplug loop to work without shell arrays
- temporary patch for typo in eventrecorder
* Thu Nov 10 2005 kay.sievers@suse.de
- version 075
- provide libvolume_id.a
- fix mount.sh #131547
- replace udeveventrecorder by a simple shell script
- don't mount usbdevfs
* Tue Nov  8 2005 kay.sievers@suse.de
- add device-mapper /dev/disk/by-name/ rules
- remove TIMEOUT values from the init script
* Mon Nov  7 2005 kay.sievers@suse.de
- version 074
  o remove all event reordering from udevd
  o we can handle TIMEOUT events proper, cause reorder queue is gone
- remove klibc build
- remove udevinitsend
* Sun Nov  6 2005 kay.sievers@suse.de
- version 072
  o move rules in daemon upstream
  o delay damonization until udevd is ready for messages
- add vio hwup rule #56865
- add experimental pnp MODALIAS fake
* Sun Oct 30 2005 kay.sievers@suse.de
- 071git20051102
  - remove some wait_for_sysfs code
  - catch-up with input changes
- remove all old "hotplug" stuff
- switch to kernel based event replay (requires kernel 2.6.14+)
- fix some permissions of the initial static nodes
- move udev rule helper programs to /lib/udev
- put static nodes to /lib/udev/devices
* Fri Oct 28 2005 kay.sievers@suse.de
- 071git20051028, put the rules-in-daemon patch in the upstream version
- get rid of static_devices and put real nodes in /etc/udev/devices
* Thu Oct 27 2005 kay.sievers@suse.de
- split udev rules into several files
- ENV{SYSCONFIG}="no" will skip SUSE specific system rules
- add "pilot" symlink to Palm devices #130167
- move Auerswald nodes to /dev/usb/auer* #129938
- add pktdvd rules #128825
- replace devmap.sh by dmsetup (hare)
- assign isdn nodes to group uucp #130229
* Thu Oct 20 2005 kay.sievers@suse.de
- udev version 071
- move static_devices handling into boot.udev
- support static_device owner+group and static_devices.local #104698
- replace over complicated udev.count_events by a shell-script
- remove klibc PATH from path_id script #117196
- remove static printer nodes
* Fri Sep  9 2005 hare@suse.de
- Added /usr/bin/udev.count_events for YaST2
* Wed Sep  7 2005 kasievers@suse.de
- fix 1394 video rules #115152
- add vbi symlink #104618
- create /dev/by-path/ for scsi optical (sr*)
- add joydev autoloading #112672
- make /dev/pmu owned by "video" group #115003
* Tue Sep  6 2005 zoz@suse.de
- fixed hwup call in macio rule (bug 114695)
* Mon Sep  5 2005 hare@suse.de
- Fix /sbin/path_id for PCMCIA devices (#104675)
- Add rules for USB jogshuttle device.
* Mon Sep  5 2005 zoz@suse.de
- Enable boot paretemer pcmcia=off
* Fri Sep  2 2005 kasievers@suse.de
- add input_device.sh from the dead hotplug package
* Fri Sep  2 2005 schwab@suse.de
- Don't provide/obsolete hotplugctl [#112953].
* Thu Sep  1 2005 kasievers@suse.de
- move lirc handling to the lirc package #114656
- add /dev/lp[0-3] to static devices #114353
* Thu Sep  1 2005 mmj@suse.de
- fix PreReq: [#114657]
* Thu Sep  1 2005 ro@suse.de
- provide and obsolete hotplug and hotplugctl
* Wed Aug 31 2005 kasievers@suse.de
- new version 066git20050829
- fixed timeout bug in daemon
- added udevdb dump to udevinfo for YAST to import the data
  instead of reading it from the db files directly (#113766)
- enforce plain printable or valid utf8 chars for device names
  and symlinks
- most commands have an up-to-date manpage now
- add macio hotplug support
* Mon Aug 29 2005 zoz@suse.de
- removed sysconfig.hotplug completely
- added sysconfig.storage with options HOTPLUG_MOUNT_FSTAB and
  HOTPLUG_CHECK_FILESYSTEMS. These control /sbin/udev.mount.sh.
* Mon Aug 29 2005 zoz@suse.de
- added udev.mount.sh that fscks and mounts storage devices that have
  a matching entry in fstab. Also added rule that calls it. (bug 112946)
- fixed debug script show_event_log
* Fri Aug 26 2005 zoz@suse.de
- fixed specfile to install README.Logging and show_event_log
* Fri Aug 26 2005 kasievers@suse.de
- new version 066git20050826
- added Hannes' IDE module loader
- add pci_express to bus list
* Thu Aug 25 2005 zoz@suse.de
- Added boot.preload_early to Should-Start: in boot.coldplug
  (on behalf of coolo)
- Added 'Obsoletes: hotplug' to specfile (bug 112951)
- Removed all rules that call openct (bug 112820)
* Thu Aug 25 2005 zoz@suse.de
- fixed 50-udev.rules: name of firmware.sh was wrong
* Wed Aug 24 2005 zoz@suse.de
- submitted the wrong set of *rc files last time. Fixed that.
* Mon Aug 22 2005 zoz@suse.de
- Removed all occurences of /etc/hotplug/functions from udev scripts
- Moved isdn.sh and firmware.hotplug.sh to /sbin/udev.*.sh
- Added README.Logging and a helper script to docdir
* Mon Aug 22 2005 kasievers@suse.de
- Version 068git20050822
  Fix some exit codes and a vol_id segfault
* Thu Aug 18 2005 kasievers@suse.de
- Upstream Version 068
* Tue Aug 16 2005 kasievers@suse.de
- New version 066git20050816
  Added ENV{KEY}="value" to export variable to environment
* Mon Aug 15 2005 zoz@suse.de
- moved some files from hotplug package to udev:
  hotplug.functions, *rc, firmware.agent, sysconfig.hotplug
- 50-udev.rules: changed filename in firmware rule
- don't call hwdown at boot.coldplug stop
* Mon Aug 15 2005 kkeil@suse.de
- make hotplug PCMCIA/USB working with ISDN (#102342)
* Mon Aug 15 2005 kasievers@suse.de
- New version 066git20050814
  add parport0 to static_devices.txt
* Sat Aug 13 2005 kasievers@suse.de
- New version 066git20050813
* Sat Aug 13 2005 zoz@suse.de
- Added patch udev.enhance_logging.patch:
  - multiline messages from called programs are no longer folded
    to a single line in syslog
  - changed loglevels of some messages.
* Fri Aug 12 2005 kay.sievers@suse.de
- New version 066git20050812
  Uses Inotify! to watch for /etc/udev/rules.d/ changes
  with automatic rules reload.
* Fri Aug  5 2005 kkeil@suse.de
- add more ISDN devices to udev.static_devices.txt
* Fri Aug  5 2005 kasievers@suse.de
- fix network rule
- prevent probing of horrible broken removable ide drives
  the ide-cs driver emits a hotplug event for the last close
  of a device and this makes a nice infinite hotplug loop
* Thu Aug  4 2005 kasievers@suse.de
- New version 065
* Fri Jul 29 2005 hare@suse.de
- Create missing isdn devices (#99339)
- Fix udev device permissions (#98864)
* Thu Jul 21 2005 hare@suse.de
- Update to 063git20050720
- udevd does not exec() the udev process anymore.
* Wed Jul 20 2005 hare@suse.de
- Update to 063git2005715
- Fix rules for device names
- Match SYSFS{} for events without device nodes.
- Add rules for alsa, openct, and isdn usb devices.
* Mon Jul 18 2005 hare@suse.de
- Update to 062git20050714.
- Fix handling of floppy devices
- Add script to create static device nodes.
* Sun Jul 10 2005 schwab@suse.de
- Fix broken ioctl (#70993).
- Fix bogus free.
* Fri Jul  8 2005 hare@suse.de
- Update to 062git20050708
- Add /etc/scsi_id.config to handle libata drives.
* Wed Jul  6 2005 hare@suse.de
- Update to 060git20050705
* Thu Jun 30 2005 hare@suse.de
- Update to 058git20050629.
  Implemented environment import rules.
* Fri Jun 24 2005 hare@suse.de
- Implement precompiled rules.
* Thu Jun 23 2005 hare@suse.de
- Update to 058git20050622
- Converted usb agent to udev rule.
* Tue Jun 21 2005 hare@suse.de
- Update to 058git20050620
- Moved boot.coldplug script from hotplug package.
- Rewrote hotplug agents as udev rules.
* Tue Jun 14 2005 hare@suse.de
- Fix event replay.
* Tue Jun 14 2005 hare@suse.de
- Fix handling of network events.
* Tue Jun 14 2005 hare@suse.de
- Update manpage to document rule operators.
* Mon Jun 13 2005 hare@suse.de
- Fix udevcontrol to return proper error state.
- Always enable DEBUG for now.
- Add script to create missing floppy devices.
* Fri Jun 10 2005 hare@suse.de
- Update to upstream package 20050608.
  All patches are now upstream.
  Total revamp of the package.
* Thu Mar 10 2005 hare@suse.de
- Delete invalid pid files on startup.
- Add rules for device-mapper targets.
- Remove cdrom links, will now be handled by YaST2.
* Wed Mar  9 2005 hare@suse.de
- Do not call udev_volume_id for removable devices (#70994).
* Mon Mar  7 2005 hare@suse.de
- Add static devices for dynamic /dev
- Make udevd using static devices if available.
* Fri Mar  4 2005 hare@suse.de
- Do not call udev_volume_id for floppy devices (#67152).
- udevinitsend binary to feed init events into udevd.
* Wed Mar  2 2005 hare@suse.de
- Always keep permissions if a correct device node exists.
- Add resmgr support.
* Tue Mar  1 2005 hare@suse.de
- Fix udev rules to work with USB devices (#66708).
- Fix permissions for /dev/dsp (#66886).
* Mon Feb 28 2005 hare@suse.de
- Check the error code from mknod (#66691).
* Mon Feb 28 2005 hare@suse.de
- use proper names for ieee1394 video devices (#66827).
- Disable logging (#66755).
- Fix spurious file '0' (#66760).
* Wed Feb 23 2005 hare@suse.de
- Disable generation of DRI nodes (#65926)
* Wed Feb 23 2005 hare@suse.de
- Fix device path for PCMCIA devices.
* Tue Feb 22 2005 hare@suse.de
- Fix ata_identify to display only printable ASCII characters.
- Add cdrom links (#65977).
* Tue Feb 22 2005 hare@suse.de
- Use per-device options instead of global configuration entries.
* Tue Feb 22 2005 hare@suse.de
- Update to udev-053
* Thu Feb 17 2005 olh@suse.de
- always quote the enviroment variables in hotplugeventrecorder
  (#50931)
* Sun Feb 13 2005 ro@suse.de
- fix build on i586 (canonicalize ARCH)
* Fri Feb 11 2005 hare@suse.de
- Update to udev-052
- Add rule option 'ignore_scripts'.
- Add config option 'udev_remove'.
* Wed Feb  9 2005 hare@suse.de
- Update to udev-051
- Split off separate package klibc-devel
- Merge udev.permissions into udev.rules.
* Thu Feb  3 2005 hare@suse.de
- Enable logging again
- Add pid file to udevd
- Add load limiting to udevd
- Update manpage
* Sun Jan 30 2005 olh@suse.de
- remove debug builds
* Fri Jan 28 2005 hare@suse.de
- Use parent device names for partitions (#46677).
* Fri Jan 28 2005 olh@suse.de
- keep device nodes on remove event
* Thu Jan 27 2005 olh@suse.de
- add a bunch of devices were kernel name doesnt match direntry
* Thu Jan 27 2005 olh@suse.de
- add mmtimer:root:root:444 to udev.permissions (#50201)
* Mon Jan 24 2005 olh@suse.de
- udev.get_unique_drive_id.sh: handle usblp (#42571)
* Mon Jan 24 2005 hare@suse.de
- Fix boot.udev to setup /proc/sys/kernel/hotplug correctly.
* Sun Jan 23 2005 olh@suse.de
- always insserv boot.udev (#50098)
* Sat Jan 22 2005 olh@suse.de
- udev.get_unique_drive_id.sh: handle targetN for usb-storage
* Fri Jan 21 2005 olh@suse.de
- fix klibc strncat for scsi_id
* Fri Jan 21 2005 olh@suse.de
- udev.get_unique_hardware_path.sh: handle targetN for usb-storage
* Fri Jan 21 2005 hare@suse.de
- Fix boot timeout for udevd
- Fix spec file to always enable udev
* Thu Jan 20 2005 hare@suse.de
- Fix empty PHYSDEVPATH for udevd
- Include hotplugeventrecorder start script from hotplug package
- Clean up obsolete patches.
* Mon Jan 17 2005 hare@suse.de
- update to udev-050
- patch udev to handle netlink messages, too.
- Update kernel-headers to 2.6.10
- Move raiddetect and other programs to extras directory.
* Tue Jan 11 2005 olaf@suse.de
- update to klibc-0.196
* Sat Jan  8 2005 olh@suse.de
- udev.get_unique_hardware_path.sh:
  handle new targetN subdir int SCSI hosts for ide-scsi
* Sun Dec 19 2004 olh@suse.de
- udev.get_unique_hardware_path.sh:
  handle new targetN subdir in SCSI hosts, introduced in 2.6.10-rc1
* Sun Dec 19 2004 olh@suse.de
- udev.get_unique_hardware_path.sh: use functions for device types
* Wed Dec 15 2004 olh@suse.de
- add dvb rules and /etc/udev/scripts/dvb.sh (#48034)
* Thu Nov 11 2004 coolo@suse.de
- fixing file list for debug packages
* Sun Nov  7 2004 olh@suse.de
- fix off by one error in ata_idetify, replace '/' with '_'
* Sat Oct 23 2004 olh@suse.de
- be non-verbose during errno creation, fix ioctl arguments
* Sat Oct 23 2004 olh@suse.de
- go back to neetbsd ash for the time being
* Sat Oct 23 2004 olh@suse.de
- update sed to 4.1.2
* Sat Oct 23 2004 olh@suse.de
- install udev_volume_id
* Sat Oct 23 2004 olh@suse.de
- update to udev 042
  update to klibc-0.190
* Tue Oct 19 2004 olh@suse.de
- update to udev 040
* Mon Oct 18 2004 olh@suse.de
- fix tree: label at end of compound statement
* Mon Oct 18 2004 olh@suse.de
- update to udev 039
  update to klibc-0.186
  update to sysfsutils-1.2.0
* Mon Oct 11 2004 olh@suse.de
- change sgi_fetchop entry in udev.permissions to sgi_* (#47090)
* Mon Oct 11 2004 olh@suse.de
- add udev.no-dev.d.patch, do not look into /etc/dev.d in udevstart
  (#45874)
* Tue Aug 31 2004 olh@suse.de
- udev.get_unique_drive_id.sh: check if scsi_generic sysfs entry
  points to a block device before changing directory
* Tue Aug 31 2004 olh@suse.de
- update description in boot.udev
  run udevstart in the background, its just to rebuild udevdb
* Wed Aug 25 2004 olh@suse.de
- fix waring in klibc cat(1)
* Wed Aug 25 2004 olh@suse.de
- do not create the /dev/cdrom symlink anymore if /dev is in tmpfs
  the real device node is now expected in /etc/fstab
* Mon Aug 23 2004 olh@suse.de
- update kernel headers to 2.6.8
  add ext2_fs_sb.h, compiler.h, gentrap.h, pal.h
* Fri Aug 20 2004 olh@suse.de
- move udevinfo.static back to /sbin
* Thu Aug 19 2004 olh@suse.de
- remove /sbin/run_init
  it has to be static because /lib is already gone when it runs
* Thu Aug 19 2004 olh@suse.de
- remove whitespaces from udev.permissions
* Thu Aug 19 2004 olh@suse.de
- update klibc-ipconfig.patch, set also provided netmask
* Tue Aug 17 2004 olh@suse.de
- add klibc-0.161-ia64-stopbit.patch, missing stopbit in syscall.S
* Tue Aug 17 2004 olh@suse.de
- add udev-030-udevsend-udev_lib.patch, make -j fails
* Thu Aug 12 2004 hare@suse.de
- Enable build of all utilities for glibc.
* Tue Aug 10 2004 olh@suse.de
- add bsd pty devnodes to udev.permissions (#42940 - LTC9911)
* Mon Aug  9 2004 hare@suse.de
- Moved dev.d rules to hotplug rpm.
* Fri Aug  6 2004 hare@suse.de
- Update dev.d rules
* Mon Aug  2 2004 hare@suse.de
- Update to udev-030 / klibc-0.153
- Added dev.d rules
* Fri Jul 16 2004 hare@suse.de
- Fix buffer overflow in udevstart.
- Add '-n' to mount and umount.
* Thu Jul 15 2004 hare@suse.de
- Fix getpagesize() for klibc.
- Update hotplugeventrecorder to sh()-ify the output.
* Wed Jul 14 2004 schwab@suse.de
- Fix for ia64.
* Fri Jul  9 2004 hare@suse.de
- Update to udev-029 / klibc-0.148.
- Added 'cat' to klibc binaries.
* Thu Jul  1 2004 olh@suse.de
- remove udev.rules entry to ignore md events again,
  raidautorun in initrd can not create devices anymore with
  this change (#42664)
* Mon Jun 28 2004 hare@suse.de
  Fix for #42525:
- Raise buffer size for symlinks to 200 bytes
- check for buffer overflow in genertated symlinks and try to
  truncate them
- Reverting last patch as it's not needed anymore
* Mon Jun 28 2004 hare@suse.de
- Shorten zfcp partition names for 100 byte limit (#42525).
* Fri Jun 25 2004 hare@suse.de
- Fix udev scripts to use 'pwd -P' to get the correct pathname.
* Wed Jun 23 2004 meissner@suse.de
- Increase serial buffer to 256. (IBM saw inquires with 168 byte
  length return on some devices) (LTC#8890 / SUSE#41991).
- Patch from Kurt Garloff, reducing default inquiry size from 255
  to 254.
* Tue Jun 22 2004 meissner@suse.de
- Added hvsi* console devices on Power5 to udev.permissions.
* Wed Jun 16 2004 olh@suse.de
- udev.get_unique_drive_id.sh: dont use page 0x80,
  restore 9.1 behaviour for by-id symlinks (#41991 - LTC8890)
* Wed Jun 16 2004 olh@suse.de
- add new z90crypt:root:root:666 to udev.permissions
- ignore md device events, especially the remove part
- remove rule for dm-* events, the external helper
  does not work (#41198 - LTC8739)
* Wed Jun  9 2004 olh@suse.de
- udev.get_unique_drive_id.sh:
  remove trailing whitespaces from s390 css0 dasd devices (#41741)
* Sat Jun  5 2004 olh@suse.de
- provide updated README.klibc.ipconfig
* Sat Jun  5 2004 olh@suse.de
- fix unlink patch, no unlink happend if a node to create was a file
  (#41808)
* Wed Jun  2 2004 olh@suse.de
- fix a format string bug in the udev.debug binary
* Tue Jun  1 2004 olh@suse.de
- remove also (possible stale) symlinks in boot.udev start
* Mon May 31 2004 olh@suse.de
- add klibc-ipconfig.patch for static interface data (#41467)
  create also /dev/dvd symlink if dev is in tmpfs
* Thu May 27 2004 olh@suse.de
- create /dev/cdrom symlink again if dev is in tmpfs
* Thu May 27 2004 olh@suse.de
- update iscsi support, use sysfs instead of iscsi-id
  klibc nfsmount, default to v3,tcp,rsize=8k,wsize=8k instead of
  v2,udp,rsize=1k,wsize=1k
* Tue May 25 2004 olh@suse.de
- add dm-ioctl.h and kdev_t.h
  keep /dev/cdrom symlink (#41104)
* Mon May 24 2004 olh@suse.de
- call /sbin/iscsi-id in udev.get_unique_drive_id.sh
* Mon May 24 2004 olh@suse.de
- fix typo in scsi type detection, /type is a file
  add a by-serial for usb-storage, using the vendor and model data
* Sun May 23 2004 olh@suse.de
- add klibc-nfsmount-bindresvport.patch
  correct initializaion for bind() arguments, fix padding (#41107)
* Wed May 19 2004 olh@suse.de
- dont print 'not handled' to stdout, it becomes a symlink
* Mon May 10 2004 olh@suse.de
- move stuff from /dev/by-path to /dev/<type>/by-path, same for -id
  will break nothing. block.agent looks for basename
* Thu May  6 2004 olh@suse.de
- reformat description in boot.udev
  fix Required-start: typo in boot.udev
  fix by-id symlinks after last change for firewire
* Thu Apr 29 2004 olh@suse.de
- back to klibc 0.115, no devel package for sles9
  add ica permissions entry. (#39493)
* Sun Apr 25 2004 olh@suse.de
- handle luns > 9 in udev.get_unique_hardware_path.sh (#39371)
  call closedir() to not run out of open files (#39371)
  do not call scsi_id for firewire drives (#38844)
  put tun devnode in /dev/net/
  update klibc to 0.116, siginfo syscall, parisc support
* Fri Apr 23 2004 ro@suse.de
- started to make it build on alpha again
  added kernel-headers, setjmp.S does not compile
- build on alpha without using klibc for now
* Sat Apr 17 2004 olh@suse.de
- make run_init less verbose
* Sat Apr 17 2004 olh@suse.de
- add raw devices to udev.rules (#39037 - LTC7618)
* Thu Apr 15 2004 olh@suse.de
- add sysfsutils-1.0.0.read_only_attr.patch (#38802 - LTC7506)
  sysfs_get_directory_attribute fails for write only attributes
* Wed Apr 14 2004 olh@suse.de
- add sgi_fetchop and iseries block devices to udev.permissions
* Mon Apr  5 2004 meissner@suse.de
- Enhance description of boot.udev (#38308)
* Sat Apr  3 2004 cadaha@suse.de
- make raiddetect FakeRAID detection program available
  needed for Promise/Highpoint/SiliconImage RAIDs (#36157)
  (has to be in instsys, will be needed in initrd too
  once it can also set up FakeRAIDs)
* Fri Apr  2 2004 olh@suse.de
- update udev.*.sh scripts
  get sysfs patch either via DEVPATH or as first option
  use correct variable for cdrom device
  use correct path while reading vendor/product id from broken
  usb-storage devices without serial numbers
* Thu Apr  1 2004 agruen@suse.de
- Add devnumber binary (reports the major/minor device number
  of a device inode); needed in the initrd.
* Tue Mar 30 2004 olh@suse.de
- USB card readers may appear as multiple scsi devices on one host
  just append the channel, id, lun info to the usb-storage-$foo file
* Tue Mar 30 2004 olh@suse.de
- the /dev/cdrom symlink was a bright idea
  it is created during install
  if /dev is a tmpfs mount, print it, otherwise leave it alone
  more than one cdrom device will break because the last device wins
* Mon Mar 29 2004 olh@suse.de
- do not create a 'cdrom' link, last device wins
* Sun Mar 28 2004 olh@suse.de
- keep the device node if the node already exists
* Mon Mar 22 2004 ro@suse.de
- fix libsysfs.so symlink
* Mon Mar 22 2004 olh@suse.de
- move libsysfs.so to /lib
  handle ide-scsi in udev.get_unique_hardware_path.sh
* Sun Mar 21 2004 olh@suse.de
- update udev.get_unique_hardware_path.sh, handle a few non-pci
  busses. keep pN at the end, fdisk can handle it better
  read only ascii data from usb-storage serial number,
  do not include spaces in serial
* Fri Mar 19 2004 hare@suse.de
- Fixed libsysfs to handle empty dlists.
- Add rules for S/390.
- Fixed build for ia64.
* Thu Mar 18 2004 olh@suse.de
- fix uninitialized variables passed to mknod (#36264)
* Thu Mar 18 2004 schwab@suse.de
- Fix use of uninitialized data.
* Thu Mar 18 2004 olh@suse.de
- fix boot.udev Default-Start line (#36407)
  clean up udev.get_unique_hardware_path.sh a bit,
  provide port info for cards with more than one interface
  add some examples about what info it can provide
* Tue Mar 16 2004 olh@suse.de
- add tree utility
* Sat Mar 13 2004 olh@suse.de
- add udev.get_unique_drive_id.sh and ata_identify
* Sat Mar 13 2004 olh@suse.de
- do not install /etc/scsi_id.config
  create /dev/mapper/control for the device mapper
* Fri Mar 12 2004 olh@suse.de
- update to current bk
  use regparm gcc options to avoid segfaults on i386
  update kernel headers to 2.6.4
  update kinit.sh and mkinitramfs
  allow an unlimited number of symlinks per rule
  add an incompatible change to the udev tdb to avoid unaligned
  memory access (#34778)
* Sun Mar  7 2004 olh@suse.de
- update to current bk
  use udevstart, udevinfo now in /usr/bin
  add /sbin/udev.get_input_lirc.sh to create /dev/input/ir symlink
* Thu Mar  4 2004 olh@suse.de
- update to udev-021
* Sun Feb 29 2004 olh@suse.de
- update to udev-019
  add simple /etc/init.d/boot.udev script
  add symlink reverse lookup to udev
* Tue Feb 24 2004 olh@suse.de
- update to sysfsutils-1.0.0
  get make_initramfs.sh out of the worksforme state
  update kinit to use the klibc binaries per default, add some
  error handling
* Mon Feb 23 2004 olh@suse.de
- update to post udev-018, klibc-0.115
* Tue Feb 17 2004 olh@suse.de
- update to post udev-017, klibc-0.108
* Mon Feb  9 2004 olh@suse.de
- update to klibc-0.105, add dummy getpgrp
* Mon Feb  9 2004 olh@suse.de
- update to current 016_bk, klibc-0.103
  fix ash build on ia64, update udev.get_unique_hardware_path.sh
* Fri Feb  6 2004 hare@suse.de
- Add GNU sed to programs.
- Reverted changes to udev.get_unique_hardware_path.sh
  as we now have a working sed.
- Removed dietlibc and busybox requirements.
* Wed Feb  4 2004 hare@suse.de
- Update ash to netbsd's sh from NetBSD 1.6.1.
- Included Henry Spencers regex package.
* Sun Feb  1 2004 olh@suse.de
- replace \{1,\} with {1,} in udev.get_unique_hardware_path.sh
  workaround for dietlibc pattern matching. (#34244)
* Sun Feb  1 2004 olh@suse.de
- add ln and mkdir to prerequires
* Fri Jan 30 2004 olh@suse.de
- update to klibc-0.101, fix permissions file,
  add default udev.rules, use /sbin/udev.get_unique_hardware_path.sh
  use sysfsutils cvs for libsysfs, use /usr/include/sysfs
* Wed Jan 28 2004 olh@suse.de
- workaround bug in klibc stdio handling
  update make_initrd.sh to handle permissions
* Tue Jan 27 2004 olh@suse.de
- update to udev-015, klibc-0.98
* Tue Jan 20 2004 olh@suse.de
- add /sbin/udevinfo
* Tue Jan 20 2004 olh@suse.de
- reconnect console properly, dont remove stdout for kernel threads
* Mon Jan 19 2004 olh@suse.de
- avoid segfault in event recorder
* Mon Jan 19 2004 olh@suse.de
- update to current bk status, improved database query options
  update udev query options in kinit.sh
* Mon Jan 19 2004 olh@suse.de
- update to current bk status
  scsi_id 0.3, kinit.sh updates
* Wed Jan 14 2004 olh@suse.de
- update to udev-013
  provide make_initrd scripts to put /dev into tmpfs,
  sample implementation with kinit and initramfs
* Fri Jan  2 2004 olh@suse.de
- update to udev-012, klibc-0.95
* Sun Dec  7 2003 olh@suse.de
- update to udev-008, klibc-0.94
  udev.conf points to udev.rules udev.permissions
  used /dev a device node directory
* Mon Dec  1 2003 uli@suse.de
- install libsysfs.a built against glibc
* Sat Nov 29 2003 olh@suse.de
- update to udev-007, klibc-0.87
* Sun Nov 23 2003 olh@suse.de
- add klibc-0.81 binaries to /lib/klibc/bin
  move /udev to /dev/udev
* Wed Nov 19 2003 olh@suse.de
- update to udev-006
  provide scsi_id
* Fri Nov  7 2003 uli@suse.de
- added missing object file to libsysfs.a
* Fri Oct 31 2003 uli@suse.de
- install libsysfs
* Tue Oct 28 2003 olh@suse.de
- update to udev-005
* Sun Aug 17 2003 olh@suse.de
- move the tdb to /var/lib/usb
  log udev pid to simple debugging
  provide example config in /etc/udev
* Tue Aug 12 2003 olh@suse.de
- initial release 0.2 with current bk updates
  put config files into /etc/udev/
  good luck!
